import React from "react";
import {
  PlusOutlined,
  CloseOutlined,
  FieldTimeOutlined,
  UserOutlined,
  SendOutlined,
  LoadingOutlined,
  PauseOutlined,
} from "@ant-design/icons";
import { Button, Tooltip, Input } from "antd";
import { useModel } from "umi";

export default function Chat() {
  const { setActiveAIChat } = useModel("appModel");
  const [focused, setFocused] = React.useState(false);

  return (
    <div className="flex-1 h-full flex flex-col">
      <div className="chat-head w-full h-40px px-10px color-#333 flex items-center justify-between">
        <i className="iconfont icon-duihua"></i>
        <span>
          <Tooltip title="新建会话">
            <Button type="text" size="small" icon={<PlusOutlined />}></Button>
          </Tooltip>
          <Tooltip title="历史记录">
            <Button
              type="text"
              size="small"
              icon={<FieldTimeOutlined />}
            ></Button>
          </Tooltip>
          <Tooltip title="关闭">
            <Button
              type="text"
              size="small"
              icon={<CloseOutlined />}
              onClick={() => setActiveAIChat(false)}
            ></Button>
          </Tooltip>
        </span>
      </div>

      <div className="chat-content flex-1 bg-#f5f5f5 px-10px">
        <div className="text-center pt-40px"><i className="iconfont icon-robot-2-line text-#333 text-32px"></i></div>
        <h2 className="text-center">询问AI助手</h2>
        <p>您好，我是AI助手，有什么可以帮您的吗？</p>
      </div>

      <div style={{
        borderColor: focused ? '#1890ff' : '#ddd'
      }} className="chat-foot bg-#f3f4f6 rounded-10px border border-solid border-1px m-10px">
        <Input.TextArea
          rows={3}
          autoSize={{ maxRows: 3, minRows: 3 }}
          placeholder="输入询问内容..."
          variant="borderless"
          onFocus={() => setFocused(true)}
          onBlur={() => setFocused(false)}
        />
        <div className="float-right p-10px">
          <Button type="primary" icon={<SendOutlined />}>发送</Button>
        </div>
      </div>
    </div>
  );
}
