import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Graph, Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";
const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);
  const generatePath = (width: number, height: number, strokeWidth: number) => {
    let path = "";
    // 开始位置
    path += `M${width - strokeWidth} ${height * 0.1}`;
    path += `L${width - strokeWidth} ${height - strokeWidth}`;
    path += `L${strokeWidth} ${height - strokeWidth}`;
    path += `L${strokeWidth} ${height * 0.1}`;
    path += `C${strokeWidth} ${height * 0.1} ${width * 0.25},${strokeWidth} ${width / 2},${strokeWidth}`;
    path += `S${width - strokeWidth} ${height * 0.1} ${width - strokeWidth} ${height * 0.1} Z`;

    return path;
  };

  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        ref={ref}
        style={{ opacity: opacity / 100 }}
      >
        <CustomInput value={label} styles={text} node={node} />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <path
            d={generatePath(size?.width, size?.height, strokeWidth)}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-apqc",
  width: 200,
  height: 150,
  effect: ["data"],
  component: component,
});

const Apqc: CompoundedComponent = {
  name: "APQC",
  icon: require("./image/apqc.png"),
  node: {
    shape: "custom-react-apqc",
    data: {
      label: "",
      ...defaultData,
    },
    ports
  },
};

export default Apqc;
