import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";
const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);

  const { width: w, height: h } = size;

  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        ref={ref}
        style={{ opacity: opacity / 100 }}
      >
        <CustomInput value={label} styles={text} node={node} />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <path
            d={`
              M ${Math.min(w*0.1,18)},${strokeWidth}
              L ${strokeWidth},${Math.min(h*0.1,15)}
              L ${strokeWidth},${h-Math.min(h*0.1,15)}
              L ${Math.min(w*0.1,18)},${h-strokeWidth}
              M ${w-Math.min(w*0.1,18)},${strokeWidth}
              L ${w-strokeWidth},${Math.min(h*0.1,15)}
              L ${w-strokeWidth},${h-Math.min(h*0.1,15)}
              L ${w-Math.min(w*0.1,18)},${h-strokeWidth}
            `}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-parentheses",
  width: 200,
  height: 140,
  effect: ["data"],
  component: component,
});

const parentheses: CompoundedComponent = {
  name: "中括号",
  icon: require("./image/parentheses.png"),
  node: {
    shape: "custom-react-parentheses",
    data: {
      label: "",
      ...defaultData,
    },
    ports,
  },
};

export default parentheses;
