import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";

const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);

  const generatePath = (width: number, height: number, strokeWidth: number) => {
    let path = "";
    // 开始位置
    path += `M ${width / 2} ${strokeWidth}`;
    path += `L ${width - strokeWidth} ${strokeWidth}`;
    path += `L ${width - strokeWidth} ${height / 2}`;
    path += `Q ${width - strokeWidth},${height - strokeWidth} ${width / 2},${height - strokeWidth}`;
    path += `Q ${strokeWidth},${height - strokeWidth} ${strokeWidth},${height / 2}`;
    path += `Q ${strokeWidth},${strokeWidth} ${width / 2},${strokeWidth} Z`;

    return path;
  };

  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        ref={ref}
        style={{ opacity: opacity / 100 }}
      >
        <CustomInput value={label} styles={text} node={node} />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <path
            d={generatePath(size?.width, size?.height, strokeWidth)}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-teardrop",
  width: 70,
  height: 70,
  effect: ["data"],
  component: component,
});

const TearDrop: CompoundedComponent = {
  name: "水滴",
  icon: require("./image/teardrop.png"),
  node: {
    shape: "custom-react-teardrop",
    data: {
      label: "",
      ...defaultData,
    },
    ports,
  },
};

export default TearDrop;
