import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";
const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);

  return (
    <div
      className="relative text-0 w-full h-full"
      ref={ref}
      style={{ opacity: opacity / 100 }}
    >
      <CustomInput value={label} styles={text} node={node} />
      <svg
        className="w-full h-full"
        viewBox={`0 0 ${size?.width} ${size?.height}`}
        xmlns="http://www.w3.org/2000/svg"
      >
        <defs>{defsContent}</defs>
        <polygon
          points={`${size?.width / 2},2 ${size?.width - 2},${size.height / 2} ${size.width / 2},${size.height - 2} 2,${size.height / 2}`}
          fill={fillContent}
          stroke={strokeColor}
          strokeDasharray={strokeDasharray}
          strokeWidth={strokeWidth}
        />
      </svg>
    </div>
  );
};

register({
  shape: "custom-react-relationship",
  width: 90,
  height: 70,
  effect: ["data"],
  component: component,
});

const relationship: CompoundedComponent = {
  name: "关系",
  icon: require("./image/relationship.png"),
  node: {
    shape: "custom-react-relationship",
    data: {
      label: "",
      ...defaultData,
    },
    ports,
  },
};

export default relationship;
