import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";
const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);

  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        ref={ref}
        style={{ opacity: opacity / 100 }}
      >
        <CustomInput value={label} styles={text} node={node} />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <rect
            x={strokeWidth}
            y={strokeWidth}
            width={size?.width - strokeWidth * 2}
            height={size?.height - strokeWidth * 2}
            fill={fillContent}
            stroke="rgb(120,120,120)"
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
          <rect
            x={strokeWidth + 5}
            y={strokeWidth + 5}
            width={size?.width - strokeWidth * 2 - 10 }
            height={size?.height - strokeWidth * 2 - 10 }
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-weakEntity",
  width: 100,
  height: 70,
  effect: ["data"],
  component: component,
});

const weakEntity: CompoundedComponent = {
  name: "弱实体",
  icon: require("./image/weakEntity.png"),
  node: {
    shape: "custom-react-weakEntity",
    data: {
      label: "",
      ...defaultData,
    },
    ports,
  },
};

export default weakEntity;
