import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";

const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);
  const { width: w, height: h } = size;
  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        style={{ opacity: opacity / 100 }}
        ref={ref}
      >
        <CustomInput
          value={label}
          styles={text}
          node={node}
          placeholder="请输入文本"
          txtStyle={{ bottom: "-60%" }}
        />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <path
            d={`
              M ${w / 2},${strokeWidth}
              L ${w - strokeWidth},${h / 2}
              L ${w / 2},${h - strokeWidth}
              L ${strokeWidth},${h / 2} Z
              M ${strokeWidth},${h / 2}
              L ${w - strokeWidth},${h / 2}
            `}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-arrange",
  width: 80,
  height: 80,
  effect: ["data"],
  component: component,
});

const arrange: CompoundedComponent = {
  name: "排序",
  icon: require("./image/arrange.png"),
  node: {
    shape: "custom-react-arrange",
    data: {
      label: "",
      ...defaultData,
    },
    ports,
  },
};

export default arrange;
