import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";
const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);

  const { width: w, height: h } = size;

  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        ref={ref}
        style={{ opacity: opacity / 100 }}
      >
        <CustomInput value={label} styles={text} node={node} />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <path
            d={`
              M ${w/6},${strokeWidth}
              L ${w-w/6},${strokeWidth}
              A ${w/6} ${h/2} 0 0 1 ${w-w/6},${h-strokeWidth}
              L ${w/6},${h-strokeWidth}
              A ${w/6} ${h/2} 0 0 1 ${w/6},${strokeWidth}
              Z
            `}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
          <path
            d={`
              M ${w-w/6},${strokeWidth}
              A ${w/6} ${h/2} 0 0 0 ${w-w/6},${h-strokeWidth}
            `}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-directData",
  width: 100,
  height: 70,
  effect: ["data"],
  component: component,
});

const directData: CompoundedComponent = {
  name: "数据库",
  icon: require("./image/directData.png"),
  node: {
    shape: "custom-react-directData",
    data: {
      label: "",
      ...defaultData,
    },
    ports,
  },
};

export default directData;
