import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";

const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);
  const { width: w, height: h } = size;
  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        style={{ opacity: opacity / 100 }}
        ref={ref}
      >
        <CustomInput value={label} styles={text} node={node} />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <path
            d={`
              M ${w / 6},${strokeWidth}
              L ${strokeWidth},${strokeWidth}
              L ${strokeWidth},${h - strokeWidth}
              L ${w / 6},${h - strokeWidth}
            `}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-leftAnnotation",
  width: 70,
  height: 100,
  effect: ["data"],
  component: component,
});

const leftAnnotation: CompoundedComponent = {
  name: "注释",
  icon: require("./image/leftAnnotation.png"),
  node: {
    shape: "custom-react-leftAnnotation",
    data: {
      label: "",
      ...defaultData,
    },
    ports: {
      ...ports,
      items: [
        {
          group: 'left',
          args: {
            dx: 2,
          },
        },
      ]
    }
  },
};

export default leftAnnotation;
