import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";

const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);
  const { width:w, height:h } = size;
  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        style={{ opacity: opacity / 100 }}
        ref={ref}
      >
        <CustomInput value={label} styles={text} node={node} />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <path
            d={`
              M ${strokeWidth},${strokeWidth}
              L ${w-strokeWidth},${strokeWidth}
              L ${w-strokeWidth},${h-Math.min(h,w)/3}
              L ${w/2},${h-strokeWidth}
              L ${strokeWidth},${h-Math.min(h,w)/3}
              L ${strokeWidth},${strokeWidth}
              Z
            `}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-offPageReference",
  width: 70,
  height: 60,
  effect: ["data"],
  component: component,
});

const offPageReference: CompoundedComponent = {
  name: "跨页引用",
  icon: require("./image/offPageReference.png"),
  node: {
    shape: "custom-react-offPageReference",
    data: {
      label: "",
      ...defaultData,
    },
    ports,
  },
};

export default offPageReference;
