import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports, defaultData } from "../../config/data";
import CustomInput from "../CustomInput";
import { useSizeHook, useShapeProps } from "@/hooks";
const component = ({ node }: { node: Node }) => {
  const { label, text, fill, stroke, opacity } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    defsContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);

  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        ref={ref}
        style={{ opacity: opacity / 100 }}
      >
        <CustomInput value={label} styles={text} node={node} />
        <svg
          className="w-full h-full"
          viewBox={`0 0 ${size?.width} ${size?.height}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <defs>{defsContent}</defs>
          <polygon
            points={`
              ${size.width * 0.2},${strokeWidth} 
              ${size.width * 0.8},${strokeWidth} 
              ${size.width - strokeWidth},${size.height / 2} 
              ${size.width * 0.8},${size.height - strokeWidth} 
              ${size.width * 0.2},${size.height - strokeWidth} 
              ${strokeWidth},${size.height / 2}
            `}
            fill={fillContent}
            stroke={strokeColor}
            strokeDasharray={strokeDasharray}
            strokeWidth={strokeWidth}
          />
        </svg>
      </div>
    </>
  );
};

register({
  shape: "custom-react-preparation",
  width: 100,
  height: 70,
  effect: ["data"],
  component: component,
});

const preparation: CompoundedComponent = {
  name: "预备",
  icon: require("./image/preparation.png"),
  node: {
    shape: "custom-react-preparation",
    data: {
      label: "预备",
      ...defaultData,
    },
    ports,
  },
};

export default preparation;
