import { ConfigProvider, Tabs } from "antd";
import React, { useEffect, useMemo } from "react";
import PageStyle from "./PageStyle";
import GraphStyle from "./GraphStyle";
import NodeAttrs from "@/components/NodeAttrs";
import { useModel } from "umi";
import InsetCss from "insert-css";
import Chat from "@/components/ai/Chat";

InsetCss(`
  .shalu-tabs {
    display: flex;
    flex-direction: column;
    height: 100%;
  }
  .shalu-tabs-content-holder {
    flex: 1;
    overflow-y: auto;
  }
  `);
export default function Config() {
  const { selectedCell } = useModel("graphModel");
  const { rightPanelTabActiveKey, setRightPanelTabActiveKey, activeAIChat } =
    useModel("appModel");

  const firstNode = useMemo(() => {
    return selectedCell.find((cell) => cell.isNode());
  }, [selectedCell]);

  const resizeRef = React.useRef<HTMLDivElement>(null);

  // 设置节点属性
  const handleSetNodeAttr = (attrs: any) => {
    firstNode?.setData({
      attrs,
    });
  };

  const tabItems = [
    {
      key: "1",
      label: `页面样式`,
      children: (
        <ConfigProvider
          componentSize="small"
          theme={{
            token: {
              colorPrimary: "#1890ff",
            },
          }}
        >
          <PageStyle />
        </ConfigProvider>
      ),
    },
    {
      key: "2",
      label: `图形样式`,
      children: (
        <ConfigProvider
          componentSize="small"
          theme={{
            token: {
              colorPrimary: "#1890ff",
            },
          }}
        >
          <GraphStyle />
        </ConfigProvider>
      ),
    },
    {
      key: "3",
      label: `节点属性`,
      children: (
        <ConfigProvider
          componentSize="small"
          theme={{
            token: {
              colorPrimary: "#1890ff",
            },
          }}
        >
          <NodeAttrs cell={firstNode} onChange={handleSetNodeAttr} />
        </ConfigProvider>
      ),
    },
  ];

  // useEffect(() => {
  //   if (selectedCell?.length) {
  //     setRightPanelTabActiveKey("2");
  //   } else {
  //     setRightPanelTabActiveKey("1");
  //   }
  // }, [selectedCell]);

  return (
    <div className="w-full h-full flex">
      <div
        className="h-full w-4px cursor-e-resize hover:bg-blue"
        ref={resizeRef}
      ></div>
      {activeAIChat ? (
        <Chat />
      ) : (
        <Tabs
          centered
          items={tabItems}
          activeKey={rightPanelTabActiveKey}
          onChange={(key) => setRightPanelTabActiveKey(key)}
        />
      )}
    </div>
  );
}
